netapp_ontap.models.export_rules API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.export_rules`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ExportRulesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ExportRules object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `allow_device_creation: bool GET POST PATCH`

    Specifies whether or not device creation is allowed.

  `allow_suid: bool GET POST PATCH`

    Specifies whether or not SetUID bits in SETATTR Op is to be honored.

  `anonymous_user: str GET POST PATCH`

    User ID To Which Anonymous Users Are Mapped.

  `chown_mode: str GET POST PATCH`

    Specifies who is authorized to change the ownership mode of a file.

    Valid choices:

    - restricted
    - unrestricted
  `clients: List[ExportClients] GET POST PATCH`

    Array of client matches

  `index: Size GET POST PATCH`

    Index of the rule within the export policy.

  `links: SelfLink GET`

    The links field of the export_rules.

  `ntfs_unix_security: str GET POST PATCH`

    NTFS export UNIX security options.

    Valid choices:

    - fail
    - ignore
  `protocols: List[str] GET POST PATCH`

    The protocols field of the export_rules.

  `ro_rule: List[str] GET POST PATCH`

    Authentication flavors that the read-only access rule governs

  `rw_rule: List[str] GET POST PATCH`

    Authentication flavors that the read/write access rule governs

  `superuser: List[str] GET POST PATCH`

    Authentication flavors that the superuser security type governs